@@ -368,13 +368,15 @@ class OclBulkImporter(object):
     ]
 
     @staticmethod
-    def post(file_path='', input_list=None, api_url_root='', api_token='', test_mode=False):
+    def post(file_path='', input_list=None, api_url_root='', api_token='', queue='',
+             test_mode=False):
         """
         Post the import to the OCL bulk import API endpoint and return the request object
         :param file_path: Full path to a file to import
         :param input_list: Python list of JSON dictionaries to import
         :param api_url_root: e.g. https://api.openconceptlab.org
         :param api_token: OCL API token for the user account that will run the import
+        :param queue: Optional bulk import queue key
         :param test_mode: Set to True to simulate the import
         """
 
@@ -390,7 +392,9 @@ class OclBulkImporter(object):
             post_data = file_handle.read()
 
         # Process the import
-        url = api_url_root + OclBulkImporter.OCL_BULK_IMPORT_API_ENDPOINT
+        url = '%s%s' % (api_url_root, OclBulkImporter.OCL_BULK_IMPORT_API_ENDPOINT)
+        if queue:
+            url += '%s/' % urllib.urlencode(queue)
         api_headers = {'Authorization': 'Token ' + api_token}
         import_response = requests.post(url, headers=api_headers, data=post_data)
         # import_response.raise_for_status()
@@ -615,7 +619,7 @@ class OclFlexImporter(object):
             "allowed_fields": ["id", "external_id", "description", "released"],
             OBJ_DEF_ATTR_HTTP_IMPORT_METHOD: {
                 ACTION_TYPE_CREATE: HTTP_METHOD_POST,
-                ACTION_TYPE_UPDATE: HTTP_METHOD_POST,
+                ACTION_TYPE_UPDATE: HTTP_METHOD_PUT,
                 ACTION_TYPE_DELETE: HTTP_METHOD_DELETE
             }
         },
@@ -651,8 +655,23 @@ class OclFlexImporter(object):
 
     def __init__(self, file_path='', input_list=None, api_url_root='', api_token='', limit=0,
                  test_mode=False, verbosity=1, do_update_if_exists=False, import_delay=0,
-                 reference_batch_size=DEFAULT_REFERENCE_BATCH_SIZE):
-        """ Initialize this object """
+                 reference_batch_size=DEFAULT_REFERENCE_BATCH_SIZE, update_progress=None):
+        """
+        Initialize this object
+
+        :param file_path:
+        :param input_list:
+        :param api_url_root:
+        :param api_token:
+        :param limit:
+        :param test_mode:
+        :param verbosity:
+        :param do_update_if_exists:
+        :param import_delay:
+        :param reference_batch_size:
+        :param update_progress: function(str) to call when progress changes
+        """
+
         self.input_list = input_list
         self.file_path = file_path
         if file_path:
@@ -668,6 +687,7 @@ class OclFlexImporter(object):
         self.reference_batch_size = reference_batch_size
         self.import_results = None
         self._cache_obj_exists = {}
+        self.update_progress = update_progress
 
         # Prepare the headers
         self.api_headers = {
@@ -703,6 +723,12 @@ class OclFlexImporter(object):
             for json_line_raw in json_file:
                 self.input_list.append(json.loads(json_line_raw))
 
+    def report_progress(self):
+        if self.update_progress:
+            self.update_progress("%s of %s" % (
+                self.import_results.count,
+                self.import_results.total_lines))
+
     def process(self):
         """
         Import a list of OCL-formatted JSON resources using the OCL API
@@ -723,6 +749,7 @@ class OclFlexImporter(object):
 
         # Loop through each JSON object
         self.import_results = OclImportResults(total_lines=total_lines)
+        self.report_progress()
         obj_def_keys = self.obj_def.keys()
         count = 0
         num_processed = 0
@@ -763,6 +790,7 @@ class OclFlexImporter(object):
                 num_skipped += 1
 
             self.log('[%s]' % self.import_results.get_detailed_summary())
+            self.report_progress()
 
             # Optionally delay before processing next row
             if self.import_delay and not self.test_mode:
